library quartz_theme;

import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

class QuartzTheme {
  static ThemeData light({MaterialColor? primary}) => _getTheme(false, primary);
  static ThemeData dark({MaterialColor? primary}) => _getTheme(true, primary);

  static ThemeData _getTheme(bool dark, MaterialColor? _primary) {
    final foreground = dark ? Colors.white : Colors.black;
    final background = dark ? Colors.black : Colors.white;
    final primary = _primary ?? (dark ? Colors.orange : Colors.deepOrange);
    final lightest = dark ? Colors.grey.shade900 : Colors.grey.shade100;
    final lighter = dark ? Colors.grey.shade800 : Colors.grey.shade200;
    final light = dark ? Colors.grey.shade700 : Colors.grey.shade300;

    return ThemeData(
      brightness: dark ? Brightness.dark : Brightness.light,
      canvasColor: background,
      primarySwatch: primary,
      primaryColor: primary,
      accentColor: primary,
      textTheme: GoogleFonts.notoSansTextTheme(
        (dark ? ThemeData.dark() : ThemeData.light()).textTheme.merge(
              TextTheme(
                headline1: TextStyle(
                  color: foreground,
                  fontSize: 36,
                  fontWeight: FontWeight.w300,
                ),
                headline2: null,
                headline3: null,
                headline4: TextStyle(
                  color: foreground,
                  fontSize: 14,
                  fontWeight: FontWeight.w400,
                ),
                headline5: null, // Large text in dialogs
                headline6: null, // Appbar.title, Alert.title
                subtitle1: TextStyle(fontSize: 14), // Primary text in lists
                subtitle2: TextStyle(fontSize: 12), // Sub text in lists
                bodyText1: TextStyle(
                    fontSize: 12,
                    fontWeight: FontWeight.bold), // Emphasized body
                bodyText2: TextStyle(fontSize: 12), // Default body
                caption: null,
                button: null,
                overline: TextStyle(
                    fontSize: 10,
                    fontWeight: FontWeight.normal,
                    letterSpacing: 0),
              ),
            ),
      ),
      cardColor: lightest,
      dialogBackgroundColor: lightest,
      dividerColor: light,
      appBarTheme: AppBarTheme(
        backwardsCompatibility: false,
        foregroundColor: foreground,
        backgroundColor: Colors.transparent,
        centerTitle: true,
        elevation: 0,
      ),
      inputDecorationTheme: InputDecorationTheme(
        border: OutlineInputBorder(borderSide: BorderSide.none),
        filled: true,
        fillColor: lightest,
        hintStyle: TextStyle(color: Colors.grey.shade500),
        floatingLabelBehavior: FloatingLabelBehavior.always,
        contentPadding: EdgeInsets.symmetric(horizontal: 16, vertical: 12),
        isDense: true,
      ),
      elevatedButtonTheme: ElevatedButtonThemeData(
        style: ButtonStyle(
          padding: MaterialStateProperty.all(
              EdgeInsets.symmetric(horizontal: 36, vertical: 0)),
          elevation: MaterialStateProperty.all(0),
        ),
      ),
      checkboxTheme: CheckboxThemeData(
        fillColor: MaterialStateProperty.resolveWith((states) {
          if (states.contains(MaterialState.selected)) {
            return primary;
          }
          return lighter;
        }),
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(4)),
        // side: BorderSide.none,
      ),
      radioTheme: RadioThemeData(
        fillColor: MaterialStateProperty.resolveWith((states) {
          if (states.contains(MaterialState.selected)) {
            return primary;
          }
          return lighter;
        }),
      ),
    );
  }
}
